Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Enum UFrameMetadataError

#[non_exhaustive]
pub enum UFrameMetadataError { EmptyPayloadEncoding, EmptyCustomEncodingId, EmptyCustomEncodingContentType, InvalidCustomEncodingContentType(String), UnspecifiedPayloadFormat, PayloadWithoutEncoding, EncodingWithoutPayload, EncodingNotRepresentable { encoding: String, }, RegisteredPayloadEncodingAlias { literal_id: String, registered: String, }, FieldNotRepresentable { field: &'static str, reason: String, }, InvalidMetadata(String), MessageBuildError(String), }
Errors returned by native frame metadata operations and projections.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyPayloadEncoding

A payload encoding was constructed without any identity component.



EmptyCustomEncodingId

A payload encoding literal id is empty.



EmptyCustomEncodingContentType

A payload encoding content type is empty.



InvalidCustomEncodingContentType(String)

A payload encoding content type is not a valid media type.



UnspecifiedPayloadFormat

UPayloadFormat::Unspecified is not a concrete payload encoding.



PayloadWithoutEncoding

Payload bytes require a payload encoding.



EncodingWithoutPayload

A payload encoding requires payload bytes.



EncodingNotRepresentable

A native payload encoding cannot be represented by legacy types.

Fields

encoding: String

Diagnostic identity of the offending encoding.



RegisteredPayloadEncodingAlias

An open identity used a literal reserved for a registered legacy row.

Fields

literal_id: String

Literal identity that aliases a registered legacy row.

registered: String

Canonical registered spelling.



FieldNotRepresentable

A semantic field cannot be represented by legacy types.

Fields

field: &'static str

Name of the offending field.

reason: String

Reason the value is not representable.



InvalidMetadata(String)

The metadata violates the validity rules for its frame message kind.



MessageBuildError(String)

Building a UMessage from projected metadata failed.