#[non_exhaustive]pub enum UFrameMetadataError {
EmptyPayloadEncoding,
EmptyCustomEncodingId,
EmptyCustomEncodingContentType,
InvalidCustomEncodingContentType(String),
UnspecifiedPayloadFormat,
PayloadWithoutEncoding,
EncodingWithoutPayload,
EncodingNotRepresentable {
encoding: String,
},
RegisteredPayloadEncodingAlias {
literal_id: String,
registered: String,
},
FieldNotRepresentable {
field: &'static str,
reason: String,
},
InvalidMetadata(String),
MessageBuildError(String),
}Expand description
Errors returned by native frame metadata operations and projections.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyPayloadEncoding
A payload encoding was constructed without any identity component.
EmptyCustomEncodingId
A payload encoding literal id is empty.
EmptyCustomEncodingContentType
A payload encoding content type is empty.
InvalidCustomEncodingContentType(String)
A payload encoding content type is not a valid media type.
UnspecifiedPayloadFormat
UPayloadFormat::Unspecified is not a concrete payload encoding.
PayloadWithoutEncoding
Payload bytes require a payload encoding.
EncodingWithoutPayload
A payload encoding requires payload bytes.
EncodingNotRepresentable
A native payload encoding cannot be represented by legacy types.
RegisteredPayloadEncodingAlias
An open identity used a literal reserved for a registered legacy row.
Fields
FieldNotRepresentable
A semantic field cannot be represented by legacy types.
Fields
InvalidMetadata(String)
The metadata violates the validity rules for its frame message kind.
MessageBuildError(String)
Building a UMessage from projected metadata failed.