pub fn try_project_frame_to_umessage(
metadata: UFrameMetadata,
payload: Option<Bytes>,
) -> Result<UMessage, UFrameMetadataError>Expand description
Projects native frame metadata and optional payload bytes into a
UMessage.
Native payload encodings without a legacy UPayloadFormat equivalent are
carried by the UAttributes open payload-encoding identity fields.
Errors
Returns an error if payload bytes and payload encoding are not both present or both absent, if the encoding is not representable, or if metadata invariants are violated.