pub struct UFrameMetadataBuilder { /* private fields */ }Expand description
Builder for native frame metadata.
Obtained from UFrameMetadata::publish, UFrameMetadata::notification,
UFrameMetadata::request, or UFrameMetadata::response. Native
selected-wire code should construct metadata through this builder instead
of going through UMessageBuilder and projecting.
Implementations
Sourceimpl UFrameMetadataBuilder
impl UFrameMetadataBuilder
Sourcepub fn with_priority(self, priority: FramePriority) -> Self
pub fn with_priority(self, priority: FramePriority) -> Self
Sets the frame priority.
Sourcepub fn with_comm_status(self, comm_status: UCode) -> Self
pub fn with_comm_status(self, comm_status: UCode) -> Self
Sets the communication status.
Sourcepub fn with_permission_level(self, permission_level: u32) -> Self
pub fn with_permission_level(self, permission_level: u32) -> Self
Sets the permission level.
Sourcepub fn with_token(self, token: impl Into<String>) -> Self
pub fn with_token(self, token: impl Into<String>) -> Self
Sets the access token.
Sourcepub fn with_traceparent(self, traceparent: impl Into<String>) -> Self
pub fn with_traceparent(self, traceparent: impl Into<String>) -> Self
Sets the W3C traceparent.
Sourcepub fn with_payload_encoding(self, payload_encoding: PayloadEncoding) -> Self
pub fn with_payload_encoding(self, payload_encoding: PayloadEncoding) -> Self
Sets the payload encoding of the frame’s payload bytes.
Sourcepub fn build(self) -> Result<UFrameMetadata, UFrameMetadataError>
pub fn build(self) -> Result<UFrameMetadata, UFrameMetadataError>
Builds and validates the frame metadata.
A fresh UUIDv7 frame id is generated unless one was supplied via
Self::with_id.
Errors
Returns an error if the metadata violates the rules of its frame message kind.